@@ -48,10 +48,10 @@ extern "C"
    * GSASL_VERSION
    *
    * Pre-processor symbol with a string that describe the header file
-   * version number.  Used together with stringprep_check_version() to
+   * version number.  Used together with gsasl_check_version() to
    * verify header file and run-time library consistency.
    */
-# define GSASL_VERSION "1.1"
+# define GSASL_VERSION "1.3.91"
 
   /**
    * GSASL_VERSION_MAJOR
@@ -73,7 +73,7 @@ extern "C"
    *
    * Since: 1.1
    */
-# define GSASL_VERSION_MINOR 1
+# define GSASL_VERSION_MINOR 3
 
   /**
    * GSASL_VERSION_PATCH
@@ -84,7 +84,7 @@ extern "C"
    *
    * Since: 1.1
    */
-# define GSASL_VERSION_PATCH 0
+# define GSASL_VERSION_PATCH 91
 
   /**
    * GSASL_VERSION_NUMBER
@@ -95,7 +95,7 @@ extern "C"
    *
    * Since: 1.1
    */
-# define GSASL_VERSION_NUMBER 0x010100
+# define GSASL_VERSION_NUMBER 0x01035b
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -198,6 +198,9 @@ extern "C"
     GSASL_DIGEST_MD5_HASHED_PASSWORD = 12,
     GSASL_QOPS = 13,
     GSASL_QOP = 14,
+    GSASL_SCRAM_ITER = 15,
+    GSASL_SCRAM_SALT = 16,
+    GSASL_SCRAM_SALTED_PASSWORD = 17,
     /* Server validation callback properties. */
     GSASL_VALIDATE_SIMPLE = 500,
     GSASL_VALIDATE_EXTERNAL = 501,
@@ -318,6 +321,11 @@ extern "C"
   extern GSASL_API int gsasl_hmac_md5 (const char *key, size_t keylen,
 				       const char *in, size_t inlen,
 				       char *outhash[16]);
+  extern GSASL_API int gsasl_sha1 (const char *in, size_t inlen,
+				   char *out[20]);
+  extern GSASL_API int gsasl_hmac_sha1 (const char *key, size_t keylen,
+					const char *in, size_t inlen,
+					char *outhash[20]);
   extern GSASL_API void gsasl_free (void *ptr);
 
   /* Get the mechanism API. */
